==> webpack-target-webextension-1.0.5.tgz: package/lib/webpack5/RuntimeModules/ChunkLoaderFallback.js <==
// @ts-check
/**
 * @param {import('webpack')} webpack
 */
module.exports = function ChunkLoaderFallbackRuntimeModule(webpack) {
  const { RuntimeModule, Template } = webpack
  class ChunkLoaderFallbackRuntimeModule extends RuntimeModule {
    constructor() {
      super('chunk loader fallback', RuntimeModule.STAGE_TRIGGER)
    }
    generate() {
      return Template.getFunctionContent(runtime)
    }
  }
  return new ChunkLoaderFallbackRuntimeModule()
}
var browser
var chrome

const runtime = function () {
  const isModern = !!(() => {
    try {
      if (typeof browser.runtime.getURL === 'function') return true
    } catch (err) { }
  })()
  const runtime = isModern ? browser : chrome
  runtime.runtime.onMessage.addListener((message, sender, sendResponse) => {
    const cond = message && message.type === 'WTW_INJECT' && sender && sender.tab && sender.tab.id != null
    if (!cond) return
    let file = message.file
    try {
      file = new URL(file).pathname
    } catch {}
    if (!file) return
    if (runtime.scripting) {
      runtime.scripting
        .executeScript({
          target: { tabId: sender.tab.id, frameIds: [sender.frameId] },
          files: [file],
        })
        .then(sendResponse)
    } else {
      const details = { frameId: sender.frameId, file }
      if (isModern) {
        runtime.tabs.executeScript(sender.tab.id, details).then(sendResponse)
      } else {
        runtime.tabs.executeScript(sender.tab.id, details, sendResponse)
      }
    }
    return true
  })
}

==> webpack-target-webextension-1.1.1.tgz: package/lib/webpack5/RuntimeModules/ChunkLoaderFallback.js <==
// @ts-check
/**
 * @param {import('webpack')} webpack
 */
module.exports = function ChunkLoaderFallbackRuntimeModule(webpack) {
  const { RuntimeModule, Template } = webpack
  class ChunkLoaderFallbackRuntimeModule extends RuntimeModule {
    constructor() {
      super('chunk loader fallback', RuntimeModule.STAGE_TRIGGER)
    }
    generate() {
      return Template.getFunctionContent(runtime)
    }
  }
  return new ChunkLoaderFallbackRuntimeModule()
}
var browser
var chrome
var URL

const runtime = function () {
  const isBrowser = !!(() => {
    try {
      if (typeof browser.runtime.getURL === 'function') return true
    } catch (err) { }
  })()
  const runtime = isBrowser ? browser : chrome
  runtime.runtime.onMessage.addListener((message, sender, sendResponse) => {
    const cond = message && message.type === 'WTW_INJECT' && sender && sender.tab && sender.tab.id != null
    if (!cond) return
    let file = message.file
    try {
      file = new URL(file).pathname
    } catch {}
    if (!file) return
    if (runtime.scripting) {
      runtime.scripting
        .executeScript({
          target: { tabId: sender.tab.id, frameIds: [sender.frameId] },
          files: [file],
        })
        .then(sendResponse)
    } else {
      const details = { frameId: sender.frameId, file, matchAboutBlank: true }
      if (isBrowser) {
        runtime.tabs.executeScript(sender.tab.id, details).then(sendResponse)
      } else {
        runtime.tabs.executeScript(sender.tab.id, details, sendResponse)
      }
    }
    return true
  })
}
